← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] ~jugmac00/launchpad:use-proper-naming-for-return-code into launchpad:master

 

Jürgen Gmach has proposed merging ~jugmac00/launchpad:use-proper-naming-for-return-code into launchpad:master.

Commit message:
Use proper naming for returncode

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)

For more details, see:
https://code.launchpad.net/~jugmac00/launchpad/+git/launchpad/+merge/436133
-- 
Your team Launchpad code reviewers is requested to review the proposed merge of ~jugmac00/launchpad:use-proper-naming-for-return-code into launchpad:master.
diff --git a/lib/lp/testing/script.py b/lib/lp/testing/script.py
index 919d4b8..ee010dc 100644
--- a/lib/lp/testing/script.py
+++ b/lib/lp/testing/script.py
@@ -20,7 +20,7 @@ def run_command(command, args=None, input=None, universal_newlines=True):
     :param input: optional text to feed to command's standard input.
     :param universal_newlines: passed to `subprocess.Popen`, defaulting to
         True.
     :return: tuple of return value, standard output, and standard error.
     """
     command_line = [command]
     if args:
@@ -38,8 +38,8 @@ def run_command(command, args=None, input=None, universal_newlines=True):
         universal_newlines=universal_newlines,
     )
     stdout, stderr = child.communicate(input)
-    result = child.wait()
-    return (result, stdout, stderr)
+    returncode = child.wait()
+    return (returncode, stdout, stderr)
 
 
 def run_script(script, args=None, input=None, universal_newlines=True):
@@ -20,7 +20,7 @@ def run_command(command, args=None, input=None, universal_newlines=True):
     :param universal_newlines: passed to `subprocess.Popen`, defaulting to
         True.
-    :return: tuple of return value, standard output, and standard error.
+    :return: tuple of returncode, standard output, and standard error.
     """
     command_line = [command]